@@ -1,9 +1,9 @@
 package Test::Smoke::BuildCFG;
 use strict;
 
-# $Id: BuildCFG.pm 619 2004-02-23 23:03:38Z abeltje $
+# $Id: BuildCFG.pm 1037 2007-04-02 21:17:19Z abeltje $
 use vars qw( $VERSION );
-$VERSION = '0.006';
+$VERSION = '0.009';
 
 use Cwd;
 use File::Spec;
@@ -195,7 +195,7 @@ sub _read {
                 $vmsg = $nameorref;
             } else {
                 require Carp;
-                Carp::carp "Cannot read buildconfigurations ($nameorref): $!";
+                Carp::carp("Cannot read buildconfigurations ($nameorref): $!");
                 $self->{_buildcfg} = $self->default_buildcfg();
                 $vmsg = "internal content";
             }
@@ -259,9 +259,9 @@ sub _parse {
             }
             if ( @targets > 1 ) {
                 require Carp;
-                Carp::carp "Multiple policy lines in one section:\n\t",
-                           join( "\n\t", @targets ),
-                           "\nWill use /$targets[0]/\n";
+                Carp::carp( "Multiple policy lines in one section:\n\t",
+                            join( "\n\t", @targets ),
+                            "\nWill use /$targets[0]/\n" );
             }
             push @{ $self->{_sections} }, 
                  { policy_target => $targets[0], 
@@ -440,6 +440,17 @@ sub default_buildcfg() {
 __EOCONFIG__
 }
 
+=item new_configuration( $config )
+
+A wrapper around C<< Test::Smoke::BuildCFG::Config->new() >> so the
+object is accessible from outside this package.
+
+=cut
+
+sub new_configuration {
+    return Test::Smoke::BuildCFG::Config->new( @_ );
+}
+
 1;
 
 =back
@@ -449,7 +460,7 @@ __EOCONFIG__
 package Test::Smoke::BuildCFG::Config;
 
 use overload
-    '""'     => sub { $_[0]->[0] },
+    '""'     => sub { $_[0]->[0] || "" },
     fallback => 1;
 
 use Text::ParseWords qw( quotewords );
@@ -546,9 +557,13 @@ Create a hash with all the build arguments as keys.
 sub _split_args {
     my $self = shift;
 
+    my $i = 0;
     $self->[2] = {
-        map { ( $_ => 1 ) } quotewords( '\s+', 1, $self->[0] )
+        map { ( $_ => $i++ ) } quotewords( '\s+', 1, $self->[0] )
     };
+    $self->[0] = join( " ", sort {
+        $self->[2]{ $a } <=> $self->[2]{ $b }
+    } keys %{ $self->[2] } ) || "";
 }
 
 =item $buildcfg->has_arg( $arg[,...] )
@@ -613,6 +628,42 @@ sub args_eq {
     return (@left || keys %copy) ? 0 : 1;
 }
 
+=item rm_arg( $arg[,..] )
+
+Simply remove the argument(s) from the list and recreate the arguments
+line.
+
+=cut
+
+sub rm_arg {
+    my $self = shift;
+
+    foreach my $arg ( @_ ) {
+        exists $self->[2]{ $arg } and delete $self->[2]{ $arg };
+    }
+    $self->[0] = join( " ", sort {
+        $self->[2]{ $a } <=> $self->[2]{ $b }
+    } keys %{ $self->[2] } ) || "";
+}
+
+=item $config->vms
+
+Redo the the commandline switches in a VMSish way.
+
+=cut
+
+sub vms {
+    my $self = shift;
+
+    return join( " ", map {
+	tr/"'//d;
+        s/^-//;
+        qq/-"$_"/;
+    } sort {
+        $self->[2]{ $a } <=> $self->[2]{ $b }
+    } keys %{ $self->[2] } ) || "";
+}
+
 1;
 
 =back
